@@ -52,16 +52,16 @@ IvvAssParser::LocationData IvvAssParser::parseLocation(const QJsonObject &stopOb
         return r;
     }
 
-    const auto id = stopObj.value(QLatin1String("ifopt")).toString();
+    const auto id = stopObj.value(IfoptUtil::identifierType()).toString();
     if (IfoptUtil::isValid(id)) {
-        r.loc.setIdentifier(QStringLiteral("ifopt"), id);
+        r.loc.setIdentifier(IfoptUtil::identifierType(), id);
     } else {
         r.loc.setIdentifier(m_locationIdentifier, id);
     }
 
     // location is a platform: split out platform name
     if (stopObj.value(QLatin1String("subtype")).toString() == QLatin1String("Post")) {
-        static QRegularExpression rx(QStringLiteral(R"((.*) \((Gleis .*)\)$)"));
+        static QRegularExpression rx(QStringLiteral(R"((.*) \(((:?Gleis|Bahnsteig) .*)\)$)"));
         const auto match = rx.match(r.loc.name());
         if (match.hasMatch()) {
             r.loc.setName(match.captured(1));
@@ -274,7 +274,7 @@ static Path parseDirections(Path &&fullPath, const QJsonArray &directions)
 
         int nextSecStart = prevSecStart;
         for (; nextSecStart < poly.size(); ++nextSecStart) {
-            if (Location::distance(lat, lon, poly[nextSecStart].y(), poly[nextSecStart].x()) == 0) {
+            if (Location::distance(lat, lon, poly[nextSecStart].y(), poly[nextSecStart].x()) < 1.0f) {
                 break;
             }
         }
